/**
*
* Name		stcjuldt -- Return date as Julian date (number of days
*		    since beginning of year)
*
* Synopsis	daynum = stcjuldt(year,month,day);
*
*		int daynum	  Number of day since beginning of year
*		int year	  The year in question.  May be in the
*				    range 0-99 or 1901-2099.
*		int month,day	  The date in question.
*
* Description	This function converts a calendar date into a "Julian
*		date" which counts the number of days since the
*		beginning of the year.	For instance, January 1 of each
*		year is Julian date 1, and December 31 is 365 in
*		non-leap years and 366 in leap years.
*
*		This algorithm is valid from 1901 to 2099.
*
* Returns	int daynum	  Returned number of the day
*
* Version	3.0  (C)Copyright Blaise Computing Inc.  1986
*
**/

#include <bstring.h>

int stcjuldt(year,month,day)
int  year,month,day;
{
     /* Given month m, day_offset[m] is the number of days in the      */
     /* the preceding months in a non-leap year.  Notice that	       */
     /* day_offset[0] is not a legal month.			       */

     static int day_offset[] = {0,  0, 31, 59, 90,120,151,
				  181,212,243,273,304,334};

     return day_offset[month]
		 + day
		 + (((month > 2) && ((year % 4) == 0)) ? 1
						       : 0);
}
