/**
*
* Name		virdrect -- Read contents of rectangular region directly
*			    from the current display page
*
* Synopsis	num_read = virdrect(u_row,u_col,l_row,l_col,buffer,option);
*
*		int  num_read	Number of spaces actually read,
*				or 0 if error.
*		int  u_row	Top row to read (0 = top of screen)
*		int  u_col	Leftmost column to read (0 = left edge)
*		int  l_row	Bottom row to read
*		int  l_col	Rightmost column to read
*		char *buffer	Space in which to put the data
*		int  option	One bit in the option value tells
*				VIRDRECT how the buffer is constructed.
*				The two possible values for this bit are:
*
*		      Value	    Meaning
*		      -----------   ------------------------------------
*		      CHARS_ONLY    Buffer contains characters only.
*		      CHAR_ATTR     Buffer contains (char,attr) pairs.
*
* Description	This function reads the contents of a rectangular region
*		directly from the current display page with or without
*		the corresponding video attributes.  The cursor is not
*		moved.	The data is read row by row.
*
*		This function works only for standard text modes (0, 1,
*		2, 3, and 7).  Use SCRDRECT for other modes.
*
*		The upper left corner of the region is (u_row,u_col),
*		where (0,0) represents the upper left corner of the
*		entire screen.	The lower right corner of the region is
*		(l_row,l_col), where (24,79) is the lower right corner
*		of an 80-by-25 screen.
*
*		Be aware that this function does NOT add a trailing NUL
*		('\0') at the end of the buffer, and that any 8-bit
*		character may be present in the buffer, depending on
*		what is in video memory.
*
* Returns	num_read	Number of character cells read,
*				or 0 if error.
*		*buffer 	Characters read from the display page
*				(perhaps with their attributes)
*
* Version	3.0  (C)Copyright Blaise Computing Inc. 1986
*
**/

#include <bquery.h>
#include <bscreen.h>
#include <bvideo.h>

int virdrect(u_row,u_col,l_row,l_col,buffer,option)
int  u_row,u_col,l_row,l_col;
char *buffer;
int  option;
{
    int device,mode,last_row,columns,act_page;
    int height,width;
    int command;
    ADS buf_ads,scn_ads;

    device = scmode(&mode,&columns,&act_page);
    if (mode > 3 && mode != 7)
	return 0;
    last_row = scrows() - 1;

    utbound(u_row,0,last_row)		   /* Force reasonable values */
    utbound(l_row,u_row,last_row)
    utbound(u_col,0,columns - 1)
    utbound(l_col,u_col,columns - 1)
    height = l_row - u_row + 1;
    width  = l_col - u_col + 1;

    utabsptr(buffer,&buf_ads);
    viads(u_row,u_col,&scn_ads);

    command = ((option & CHAR_ATTR) ? 6 : 5);
    if (   mode      == 7
	|| scequip() == IBM_CV
	|| device    == b_ega)
	command |= 0x8000;	      /* Need not await retrace       */

    vidirect(&scn_ads,&buf_ads,height,width,columns * 2,
		  0,command);
    return height * width;
}
